@@ -1,4 +1,4 @@
-#    Copyright (C) 2012-2017 Germar Reitze
+#    Copyright (C) 2012-2019 Germar Reitze
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -31,16 +31,22 @@ if __name__ == '__main__':
     return password.
     """
     cfg = config.Config()
-    tools.load_env(cfg.get_cron_env_file())
+    tools.envLoad(cfg.cronEnvFile())
 
     profile_id = os.getenv('ASKPASS_PROFILE_ID', '1')
     mode = os.getenv('ASKPASS_MODE', 'local')
 
+    if mode == 'USER':
+        prompt = os.getenv('ASKPASS_PROMPT', None)
+        pw = password.Password(cfg)
+        print(pw.passwordFromUser(None, prompt = prompt))
+        sys.exit(0)
+
     temp_file = os.getenv('ASKPASS_TEMP')
     if temp_file is None:
         #normal mode, get password from module password
         pw = password.Password(cfg)
-        print(pw.get_password(None, profile_id, mode))
+        print(pw.password(None, profile_id, mode))
         sys.exit(0)
 
     #temp mode
