@@ -1,5 +1,5 @@
 #    Back In Time
-#    Copyright (C) 2008-2017 Oprea Dan, Bart de Koning, Richard Bailey, Germar Reitze
+#    Copyright (C) 2008-2019 Oprea Dan, Bart de Koning, Richard Bailey, Germar Reitze
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -19,7 +19,10 @@ import os
 import sys
 import gettext
 import argparse
+import atexit
 import subprocess
+from datetime import datetime
+from time import sleep
 
 import config
 import logger
@@ -31,6 +34,7 @@ import password
 import encfstools
 import cli
 from exceptions import MountException
+from applicationinstance import ApplicationInstance
 
 _=gettext.gettext
 
@@ -40,22 +44,28 @@ RETURN_NO_CFG = 2
 
 parsers = {}
 
-def take_snapshot_now_async( cfg ):
-    '''fork a new backintime process with 'backup' command which will
+def takeSnapshotAsync(cfg, checksum = False):
+    """
+    Fork a new backintime process with 'backup' command which will
     take a new snapshot in background.
 
-    cfg:    config.Config instance
-    '''
+    Args:
+        cfg (config.Config): config that should be used
+    """
     cmd = []
-    if cfg.is_run_ionice_from_user_enabled():
+    if cfg.ioniceOnUser():
         cmd.extend(('ionice', '-c2', '-n7'))
     cmd.append('backintime')
-    if '1' != cfg.get_current_profile():
-        cmd.extend(('--profile-id', str(cfg.get_current_profile())))
+    if '1' != cfg.currentProfile():
+        cmd.extend(('--profile-id', str(cfg.currentProfile())))
     if cfg._LOCAL_CONFIG_PATH is not cfg._DEFAULT_CONFIG_PATH:
         cmd.extend(('--config', cfg._LOCAL_CONFIG_PATH))
+    if cfg._LOCAL_DATA_FOLDER is not cfg._DEFAULT_LOCAL_DATA_FOLDER:
+        cmd.extend(('--share-path', cfg.DATA_FOLDER_ROOT))
     if logger.DEBUG:
         cmd.append('--debug')
+    if checksum:
+        cmd.append('--checksum')
     cmd.append('backup')
 
     # child process need to start its own ssh-agent because otherwise
@@ -68,45 +78,56 @@ def take_snapshot_now_async( cfg ):
             pass
     subprocess.Popen(cmd, env = env)
 
-def take_snapshot( cfg, force = True ):
-    '''take a new snapshot.
+def takeSnapshot(cfg, force = True):
+    """
+    Take a new snapshot.
 
-    cfg:    config.Config instance
-    force:  take the snapshot even if it wouldn't need to or would be
-            prevented (e.g. running on battery)
-    '''
-    tools.load_env(cfg.get_cron_env_file())
-    ret = snapshots.Snapshots( cfg ).take_snapshot( force )
+    Args:
+        cfg (config.Config):    config that should be used
+        force (bool):           take the snapshot even if it wouldn't need to
+                                or would be prevented (e.g. running on battery)
+
+    Returns:
+        bool:                   ``True`` if there was an error
+    """
+    tools.envLoad(cfg.cronEnvFile())
+    ret = snapshots.Snapshots(cfg).backup(force)
     return ret
 
 def _mount(cfg):
-    '''mount external filesystems.
+    """
+    Mount external filesystems.
 
-    cfg:    config.Config instance
-    '''
+    Args:
+        cfg (config.Config):    config that should be used
+    """
     try:
         hash_id = mount.Mount(cfg = cfg).mount()
     except MountException as ex:
         logger.error(str(ex))
         sys.exit(RETURN_ERR)
     else:
-        cfg.set_current_hash_id(hash_id)
+        cfg.setCurrentHashId(hash_id)
 
 def _umount(cfg):
-    '''unmount external filesystems.
+    """
+    Unmount external filesystems.
 
-    cfg:    config.Config instance
-    '''
+    Args:
+        cfg (config.Config):    config that should be used
+    """
     try:
         mount.Mount(cfg = cfg).umount(cfg.current_hash_id)
     except MountException as ex:
         logger.error(str(ex))
 
-def create_parsers(app_name = 'backintime'):
-    '''define parsers for commandline arguments.
+def createParsers(app_name = 'backintime'):
+    """
+    Define parsers for commandline arguments.
 
-    app_name:   string representing the current application
-    '''
+    Args:
+        app_name (str):         string representing the current application
+    """
     global parsers
 
     #define debug
@@ -121,7 +142,14 @@ def create_parsers(app_name = 'backintime'):
                                  metavar = 'PATH',
                                  type = str,
                                  action = 'store',
-                                 help = 'Read config from %(metavar)s.')
+                                 help = 'Read config from %(metavar)s. ' +
+                                        'Default = ~/.config/backintime/config')
+
+    configArgsParser.add_argument('--share-path',
+                                 metavar = 'PATH',
+                                 type = str,
+                                 action = 'store',
+                                 help = 'Write runtime data (locks, messages, log and mountpoints) to %(metavar)s.')
 
     #define common arguments which are used for all commands
     commonArgsParser = argparse.ArgumentParser(add_help = False, parents = [configArgsParser, debugArgsParser])
@@ -246,7 +274,7 @@ def create_parsers(app_name = 'backintime'):
     command = 'decode'
     nargs = '*'
     aliases.append((command, nargs))
-    description = "Decode pathes with 'encfsctl decode'"
+    description = "Decode paths with 'encfsctl decode'"
     decodeCP =             subparsers.add_parser(command,
                                                  epilog = epilogCommon,
                                                  help = description,
@@ -352,7 +380,7 @@ def create_parsers(app_name = 'backintime'):
                                                  action = 'store',
                                                  nargs = '?',
                                                  help = 'Which SNAPSHOT_ID should be used. This can be a snapshot ID or ' +\
-                                                 'an integer starting with 0 for the last snapshot, 1 for the overlast, ... ' +\
+                                                 'an integer starting with 0 for the last snapshot, 1 for the second to last, ... ' +\
                                                  'the very first snapshot is -1')
 
     restoreCP.add_argument                      ('--delete',
@@ -369,6 +397,31 @@ def create_parsers(app_name = 'backintime'):
                                                  help = 'Temporary disable creation of backup files before changing local files. ' +\
                                                  'This can be switched of permanently in Settings, too.')
 
+    restoreCP.add_argument                      ('--only-new',
+                                                 action = 'store_true',
+                                                 help = 'Only restore files which does not exist or are newer than ' +\
+                                                        'those in destination. Using "rsync --update" option.')
+
+    command = 'shutdown'
+    nargs = 0
+    description = 'Shutdown the computer after the snapshot is done.'
+    shutdownCP =           subparsers.add_parser(command,
+                                                 epilog = epilogCommon,
+                                                 help = description,
+                                                 description = description)
+    shutdownCP.set_defaults(func = shutdown)
+    parsers[command] = shutdownCP
+
+    command = 'smart-remove'
+    nargs = 0
+    description = 'Remove snapshots based on "Smart Remove" pattern.'
+    smartRemoveCP =        subparsers.add_parser(command,
+                                                 epilog = epilogCommon,
+                                                 help = description,
+                                                 description = description)
+    smartRemoveCP.set_defaults(func = smartRemove)
+    parsers[command] = smartRemoveCP
+
     command = 'snapshots-list'
     nargs = 0
     aliases.append((command, nargs))
@@ -428,23 +481,28 @@ def create_parsers(app_name = 'backintime'):
                            action = PseudoAliasAction,
                            help = argparse.SUPPRESS)
 
-def start_app(app_name = 'backintime'):
-    '''start the requested command or return config if there was no command
+def startApp(app_name = 'backintime'):
+    """
+    Start the requested command or return config if there was no command
     in arguments.
 
-    app_name:   string representing the current application
-    '''
-    create_parsers(app_name)
+    Args:
+        app_name (str): string representing the current application
+
+    Returns:
+        config.Config:  current config if no command was given in arguments
+    """
+    createParsers(app_name)
     #open log
     logger.APP_NAME = app_name
     logger.openlog()
 
     #parse args
-    args = arg_parse(None)
+    args = argParse(None)
 
     #add source path to $PATH environ if running from source
-    if tools.running_from_source():
-        tools.add_source_to_path_environ()
+    if tools.runningFromSource():
+        tools.addSourceToPathEnviron()
 
     #warn about sudo
     if tools.usingSudo() and os.getenv('BIT_SUDO_WARNING_PRINTED', 'false') == 'false':
@@ -462,22 +520,28 @@ def start_app(app_name = 'backintime'):
         printHeader()
         return getConfig(args, False)
 
-def arg_parse(args):
-    '''parse arguments given on commandline.
+def argParse(args):
+    """
+    Parse arguments given on commandline.
 
-    args:   argparse.ArgumentParser instance that should be enhanced or None
+    Args:
+        args (argparse.Namespace):  Namespace that should be enhanced
+                                    or ``None``
 
-    tests:
-    test/test_argparser.TestArgParser.*    (all of them)
-    '''
+    Returns:
+        argparser.Namespace:        new parsed Namespace
+    """
     def join(args, subArgs):
-        '''add new arguments to existing ArgumentParser.
+        """
+        Add new arguments to existing Namespace.
 
-        args:       main argparse.ArgumentParser instance that should
-                    get new arguments
-        subArgs:    second argparse.ArgumentParser instance which have
-                    new arguments that should be merged into args
-        '''
+        Args:
+            args (argparse.Namespace):
+                        main Namespace that should get new arguments
+            subArgs (argparse.Namespace):
+                        second Namespace which have new arguments
+                        that should be merged into ``args``
+        """
         for key, value in vars(subArgs).items():
             #only add new values if it isn't set already or if there really IS a value
             if getattr(args, key, None) is None or value:
@@ -485,15 +549,18 @@ def arg_parse(args):
 
     #first parse the main parser without subparsers
     #otherwise positional args in subparsers will be to greedy
+    #but only if -h or --help is not involved because otherwise
+    #help will not work for subcommands
     mainParser = parsers['main']
     sub = []
-    for i in mainParser._actions:
-        if isinstance(i, argparse._SubParsersAction):
-            #remove subparsers
-            mainParser._remove_action(i)
-            sub.append(i)
+    if '-h' not in sys.argv and '--help' not in sys.argv:
+        for i in mainParser._actions:
+            if isinstance(i, argparse._SubParsersAction):
+                #remove subparsers
+                mainParser._remove_action(i)
+                sub.append(i)
     args, unknownArgs = mainParser.parse_known_args(args)
-    #readd subparsers again
+    #read subparsers again
     if sub:
         [mainParser._add_action(i) for i in sub]
 
@@ -524,10 +591,11 @@ def arg_parse(args):
     return args
 
 def printHeader():
-    '''print application name, version and legal notes.
-    '''
+    """
+    Print application name, version and legal notes.
+    """
     version = config.Config.VERSION
-    ref, hashid = tools.get_git_ref_hash()
+    ref, hashid = tools.gitRevisionAndHash()
     if ref:
         version += " git branch '{}' hash '{}'".format(ref, hashid)
     print('')
@@ -540,16 +608,19 @@ def printHeader():
     print('')
 
 class PseudoAliasAction(argparse.Action):
-    '''translate '--COMMAND' into 'COMMAND' for backwards compatibility.
-    '''
+    """
+    Translate '--COMMAND' into 'COMMAND' for backwards compatibility.
+    """
     def __call__(self, parser, namespace, values, option_string=None):
-        '''translate '--COMMAND' into 'COMMAND' for backwards compatibility.
+        """
+        Translate '--COMMAND' into 'COMMAND' for backwards compatibility.
 
-        parser:
-        namespace:
-        values:
-        option_string:
-        '''
+        Args:
+            parser (argparse.ArgumentParser): NotImplemented
+            namespace (argparse.Namespace):   Namespace that should get modified
+            values:                           NotImplemented
+            option_string:                    NotImplemented
+        """
         #TODO: find a more elegant way to solve this
         dest = self.dest.replace('_', '-')
         if self.dest == 'b':
@@ -563,176 +634,317 @@ class PseudoAliasAction(argparse.Action):
         setattr(namespace, 'alias', alias)
 
 def aliasParser(args):
-    '''call commands which where given with leading -- for backwards
+    """
+    Call commands which where given with leading -- for backwards
     compatibility.
 
-    args:   argparse.ArgumentParser instance
-    '''
-    logger.info("Run command '%(alias)s' instead of argument '%(replace)s' due to backwards compatibility."
-                % {'alias': args.alias, 'replace': args.replace})
+    Args:
+        args (argparse.Namespace):
+                        previously parsed arguments
+    """
+    if not args.quiet:
+        logger.info("Run command '%(alias)s' instead of argument '%(replace)s' due to backwards compatibility."
+                    % {'alias': args.alias, 'replace': args.replace})
     argv = [w.replace(args.replace, args.alias) for w in sys.argv[1:]]
-    newArgs = arg_parse(argv)
+    newArgs = argParse(argv)
     if 'func' in dir(newArgs):
         newArgs.func(newArgs)
 
 def getConfig(args, check = True):
-    '''load config and change to profile selected on commandline.
+    """
+    Load config and change to profile selected on commandline.
 
-    args:   argparse.ArgumentParser instance
-    check:  if there is no valid config call sys.exit
-    '''
-    cfg = config.Config(args.config)
+    Args:
+        args (argparse.Namespace):
+                        previously parsed arguments
+        check (bool):   if ``True`` check if config is valid
+
+    Returns:
+        config.Config:  current config with requested profile selected
+
+    Raises:
+        SystemExit:     1 if ``profile`` or ``profile_id`` is no valid profile
+                        2 if ``check`` is ``True`` and config is not configured
+    """
+    cfg = config.Config(config_path = args.config, data_path = args.share_path)
     logger.debug('config file: %s' % cfg._LOCAL_CONFIG_PATH)
-    logger.debug('profiles: %s' % cfg.get_profiles())
+    logger.debug('share path: %s' % cfg._LOCAL_DATA_FOLDER)
+    logger.debug('profiles: %s' % ', '.join('%s=%s' % (x, cfg.profileName(x))
+                                                        for x in cfg.profiles()))
+
     if 'profile_id' in args and args.profile_id:
-        if not cfg.set_current_profile(args.profile_id):
+        if not cfg.setCurrentProfile(args.profile_id):
             logger.error('Profile-ID not found: %s' % args.profile_id)
             sys.exit(RETURN_ERR)
     if 'profile' in args and args.profile:
-        if not cfg.set_current_profile_by_name(args.profile):
+        if not cfg.setCurrentProfileByName(args.profile):
             logger.error('Profile not found: %s' % args.profile)
             sys.exit(RETURN_ERR)
-    if check and not cfg.is_configured():
+    if check and not cfg.isConfigured():
         logger.error('%(app)s is not configured!' %{'app': cfg.APP_NAME})
         sys.exit(RETURN_NO_CFG)
     if 'checksum' in args:
-        cfg.force_use_checksum = args.checksum
+        cfg.forceUseChecksum = args.checksum
     return cfg
 
 def setQuiet(args):
-    '''redirect sys.stdout to /dev/null if --quiet was set on commandline.
-    Return the original sys.stdout fileobject which can be used to print
-    absolute necessary information.
+    """
+    Redirect :py:data:`sys.stdout` to ``/dev/null`` if ``--quiet`` was set on
+    commandline. Return the original :py:data:`sys.stdout` file object which can
+    be used to print absolute necessary information.
 
-    args:   argparse.ArgumentParser instance
-    '''
+    Args:
+        args (argparse.Namespace):
+                        previously parsed arguments
+
+    Returns:
+        sys.stdout:     default sys.stdout
+    """
     force_stdout = sys.stdout
     if args.quiet:
+        # do not replace with subprocess.DEVNULL - will not work
         sys.stdout = open(os.devnull, 'w')
+        atexit.register(sys.stdout.close)
+        atexit.register(force_stdout.close)
     return force_stdout
 
 class printLicense(argparse.Action):
-    '''print custom license
-    '''
+    """
+    Print custom license
+    """
     def __init__(self, *args, **kwargs):
         super(printLicense, self).__init__(*args, **kwargs)
 
     def __call__(self, *args, **kwargs):
         cfg = config.Config()
-        print(cfg.get_license())
+        print(cfg.license())
         sys.exit(RETURN_OK)
 
 def backup(args, force = True):
-    '''command for taking a new snapshot.
+    """
+    Command for force taking a new snapshot.
 
-    force:  take the snapshot even if it wouldn't need to or would be
-    args:   argparse.ArgumentParser instance
-            prevented (e.g. running on battery)
-    '''
+    Args:
+        args (argparse.Namespace):
+                        previously parsed arguments
+        force (bool):   take the snapshot even if it wouldn't need to or would
+                        be prevented (e.g. running on battery)
+
+    Raises:
+        SystemExit:     0 if successful, 1 if not
+    """
     setQuiet(args)
     printHeader()
     cfg = getConfig(args)
-    ret = take_snapshot(cfg, force)
-    sys.exit(int(not ret))
+    ret = takeSnapshot(cfg, force)
+    sys.exit(int(ret))
 
 def backupJob(args):
-    '''command for force taking a new snapshot.
+    """
+    Command for taking a new snapshot in background. Mainly used for cronjobs.
+    This will run the snapshot inside a daemon and detach from it. It will
+    return immediately back to commandline.
 
-    args:   argparse.ArgumentParser instance
-    '''
+    Args:
+        args (argparse.Namespace):
+                        previously parsed arguments
+
+    Raises:
+        SystemExit:     0
+    """
     cli.BackupJobDaemon(backup, args).start()
 
-def snapshotsPath(args):
-    '''command for printing the full snapshot path of current profile.
+def shutdown(args):
+    """
+    Command for shutting down the computer after the current snapshot has
+    finished.
 
-    args:   argparse.ArgumentParser instance
-    '''
+    Args:
+        args (argparse.Namespace):
+                        previously parsed arguments
+
+    Raises:
+        SystemExit:     0 if successful; 1 if it failed either because there is
+                        no active snapshot for this profile or shutdown is not
+                        supported.
+    """
+    setQuiet(args)
+    printHeader()
+    cfg = getConfig(args)
+
+    sd = tools.ShutDown()
+    if not sd.canShutdown():
+        logger.warning('Shutdown is not supported.')
+        sys.exit(RETURN_ERR)
+
+    instance = ApplicationInstance(cfg.takeSnapshotInstanceFile(), False)
+    profile = '='.join((cfg.currentProfile(), cfg.profileName()))
+    if not instance.busy():
+        logger.info('There is no active snapshot for profile %s. Skip shutdown.'
+                    %profile)
+        sys.exit(RETURN_ERR)
+
+    print('Shutdown is waiting for the snapshot in profile %s to end.\nPress CTRL+C to interrupt shutdown.\n'
+          %profile)
+    sd.activate_shutdown = True
+    try:
+        while instance.busy():
+            logger.debug('Snapshot is still active. Wait for shutdown.')
+            sleep(5)
+    except KeyboardInterrupt:
+        print('Shutdown interrupted.')
+    else:
+        logger.info('Shutdown now.')
+        sd.shutdown()
+    sys.exit(RETURN_OK)
+
+def snapshotsPath(args):
+    """
+    Command for printing the full snapshot path of current profile.
+
+    Args:
+        args (argparse.Namespace):
+                        previously parsed arguments
+
+    Raises:
+        SystemExit:     0
+    """
     force_stdout = setQuiet(args)
     cfg = getConfig(args)
     if args.keep_mount:
         _mount(cfg)
-    print('SnapshotsPath: %s' % cfg.get_snapshots_full_path(), file=force_stdout)
+    if args.quiet:
+        msg = '{}'
+    else:
+        msg = 'SnapshotsPath: {}'
+    print(msg.format(cfg.snapshotsFullPath()), file=force_stdout)
     sys.exit(RETURN_OK)
 
 def snapshotsList(args):
-    '''command for printing a list of all snapshots in current profile.
+    """
+    Command for printing a list of all snapshots in current profile.
 
-    args:   argparse.ArgumentParser instance
-    '''
+    Args:
+        args (argparse.Namespace):
+                        previously parsed arguments
+
+    Raises:
+        SystemExit:     0
+    """
     force_stdout = setQuiet(args)
     cfg = getConfig(args)
     _mount(cfg)
-    s = snapshots.Snapshots(cfg)
-    snapshots_list = s.get_snapshots_list()
-    if snapshots_list:
-        for snapshot_id in snapshots_list:
-            print('SnapshotID: %s' % snapshot_id, file=force_stdout)
+
+    if args.quiet:
+        msg = '{}'
     else:
-        logger.error("There are no snapshots in '%s'" % cfg.get_profile_name())
+        msg = 'SnapshotID: {}'
+    no_sids = True
+    #use snapshots.listSnapshots instead of iterSnapshots because of sorting
+    for sid in snapshots.listSnapshots(cfg, reverse = False):
+        print(msg.format(sid), file=force_stdout)
+        no_sids = False
+    if no_sids:
+        logger.error("There are no snapshots in '%s'" % cfg.profileName())
     if not args.keep_mount:
         _umount(cfg)
     sys.exit(RETURN_OK)
 
 def snapshotsListPath(args):
-    '''command for printing a list of all snapshots pathes in current profile.
+    """
+    Command for printing a list of all snapshots pathes in current profile.
 
-    args:   argparse.ArgumentParser instance
-    '''
+    Args:
+        args (argparse.Namespace):
+                        previously parsed arguments
+
+    Raises:
+        SystemExit:     0
+    """
     force_stdout = setQuiet(args)
     cfg = getConfig(args)
     _mount(cfg)
-    s = snapshots.Snapshots(cfg)
-    snapshots_list = s.get_snapshots_list()
-    if snapshots_list:
-        for snapshot_id in snapshots_list:
-            print('SnapshotPath: %s' % s.get_snapshot_path(snapshot_id), file=force_stdout)
+
+    if args.quiet:
+        msg = '{}'
     else:
-        logger.error("There are no snapshots in '%s'" % cfg.get_profile_name())
+        msg = 'SnapshotPath: {}'
+    no_sids = True
+    #use snapshots.listSnapshots instead of iterSnapshots because of sorting
+    for sid in snapshots.listSnapshots(cfg, reverse = False):
+        print(msg.format(sid.path()), file=force_stdout)
+        no_sids = False
+    if no_sids:
+        logger.error("There are no snapshots in '%s'" % cfg.profileName())
     if not args.keep_mount:
         _umount(cfg)
     sys.exit(RETURN_OK)
 
 def lastSnapshot(args):
-    '''command for printing the very last snapshot in current profile.
+    """
+    Command for printing the very last snapshot in current profile.
 
-    args:   argparse.ArgumentParser instance
-    '''
+    Args:
+        args (argparse.Namespace):
+                        previously parsed arguments
+
+    Raises:
+        SystemExit:     0
+    """
     force_stdout = setQuiet(args)
     cfg = getConfig(args)
     _mount(cfg)
-    s = snapshots.Snapshots(cfg)
-    snapshots_list = s.get_snapshots_list()
-    if snapshots_list:
-        print('SnapshotID: %s' % snapshots_list[0], file=force_stdout)
+    sid = snapshots.lastSnapshot(cfg)
+    if sid:
+        if args.quiet:
+            msg = '{}'
+        else:
+            msg = 'SnapshotID: {}'
+        print(msg.format(sid), file=force_stdout)
     else:
-        logger.error("There are no snapshots in '%s'" % cfg.get_profile_name())
+        logger.error("There are no snapshots in '%s'" % cfg.profileName())
     _umount(cfg)
     sys.exit(RETURN_OK)
 
 def lastSnapshotPath(args):
-    '''command for printing the path of the very last snapshot in
+    """
+    Command for printing the path of the very last snapshot in
     current profile.
 
-    args:   argparse.ArgumentParser instance
-    '''
+    Args:
+        args (argparse.Namespace):
+                        previously parsed arguments
+
+    Raises:
+        SystemExit:     0
+    """
     force_stdout = setQuiet(args)
     cfg = getConfig(args)
     _mount(cfg)
-    s = snapshots.Snapshots(cfg)
-    snapshots_list = s.get_snapshots_list()
-    if snapshots_list:
-        print('SnapshotPath: %s' % s.get_snapshot_path(snapshots_list[0]), file=force_stdout)
+    sid = snapshots.lastSnapshot(cfg)
+    if sid:
+        if args.quiet:
+            msg = '{}'
+        else:
+            msg = 'SnapshotPath: {}'
+        print(msg.format(sid.path()), file=force_stdout)
     else:
-        logger.error("There are no snapshots in '%s'" % cfg.get_profile_name())
+        logger.error("There are no snapshots in '%s'" % cfg.profileName())
     if not args.keep_mount:
         _umount(cfg)
     sys.exit(RETURN_OK)
 
 def unmount(args):
-    '''command for unmounting all filesystems.
+    """
+    Command for unmounting all filesystems.
 
-    args:   argparse.ArgumentParser instance
-    '''
+    Args:
+        args (argparse.Namespace):
+                        previously parsed arguments
+
+    Raises:
+        SystemExit:     0
+    """
     setQuiet(args)
     cfg = getConfig(args)
     _mount(cfg)
@@ -740,27 +952,39 @@ def unmount(args):
     sys.exit(RETURN_OK)
 
 def benchmarkCipher(args):
-    '''command for transfering a file with scp to remote host with all
+    """
+    Command for transferring a file with scp to remote host with all
     available ciphers and print its speed and time.
 
-    args:   argparse.ArgumentParser instance
-    '''
+    Args:
+        args (argparse.Namespace):
+                        previously parsed arguments
+
+    Raises:
+        SystemExit:     0
+    """
     setQuiet(args)
     printHeader()
     cfg = getConfig(args)
-    if cfg.get_snapshots_mode() in ('ssh', 'ssh_encfs'):
+    if cfg.snapshotsMode() in ('ssh', 'ssh_encfs'):
         ssh = sshtools.SSH(cfg)
-        ssh.benchmark_cipher(args.FILE_SIZE)
+        ssh.benchmarkCipher(args.FILE_SIZE)
         sys.exit(RETURN_OK)
     else:
-        logger.error("SSH is not configured for profile '%s'!" % cfg.get_profile_name())
+        logger.error("SSH is not configured for profile '%s'!" % cfg.profileName())
         sys.exit(RETURN_ERR)
 
 def pwCache(args):
-    '''command for starting password cache daemon.
+    """
+    Command for starting password cache daemon.
 
-    args:   argparse.ArgumentParser instance
-    '''
+    Args:
+        args (argparse.Namespace):
+                        previously parsed arguments
+
+    Raises:
+        SystemExit:     0 if daemon is running, 1 if not
+    """
     force_stdout = setQuiet(args)
     printHeader()
     cfg = getConfig(args)
@@ -781,15 +1005,21 @@ def pwCache(args):
     sys.exit(ret)
 
 def decode(args):
-    '''command for decoding pathes given pathes with 'encfsctl'.
+    """
+    Command for decoding paths given paths with 'encfsctl'.
     Will listen on stdin if no path was given.
 
-    args:   argparse.ArgumentParser instance
-    '''
+    Args:
+        args (argparse.Namespace):
+                        previously parsed arguments
+
+    Raises:
+        SystemExit:     0
+    """
     force_stdout = setQuiet(args)
     cfg = getConfig(args)
-    if cfg.get_snapshots_mode() not in ('local_encfs', 'ssh_encfs'):
-        logger.error("Profile '%s' is not encrypted." % cfg.get_profile_name())
+    if cfg.snapshotsMode() not in ('local_encfs', 'ssh_encfs'):
+        logger.error("Profile '%s' is not encrypted." % cfg.profileName())
         sys.exit(RETURN_ERR)
     _mount(cfg)
     d = encfstools.Decode(cfg)
@@ -809,11 +1039,17 @@ def decode(args):
     sys.exit(RETURN_OK)
 
 def remove(args, force = False):
-    '''command for removing snapshots.
+    """
+    Command for removing snapshots.
 
-    args:   argparse.ArgumentParser instance
-    force:  don't ask before removing (BE CAREFUL!)
-    '''
+    Args:
+        args (argparse.Namespace):
+                        previously parsed arguments
+        force (bool):   don't ask before removing (BE CAREFUL!)
+
+    Raises:
+        SystemExit:     0
+    """
     setQuiet(args)
     printHeader()
     cfg = getConfig(args)
@@ -823,52 +1059,107 @@ def remove(args, force = False):
     sys.exit(RETURN_OK)
 
 def removeAndDoNotAskAgain(args):
-    '''command for removing snapshots without asking before remove
+    """
+    Command for removing snapshots without asking before remove
     (BE CAREFUL!)
 
-    args:   argparse.ArgumentParser instance
-    '''
+    Args:
+        args (argparse.Namespace):
+                        previously parsed arguments
+
+    Raises:
+        SystemExit:     0
+    """
     remove(args, True)
 
-def restore(args):
-    '''command for restoring files from snapshots.
+def smartRemove(args):
+    """
+    Command for running Smart-Remove from Terminal.
 
-    args:   argparse.ArgumentParser instance
-    '''
+    Args:
+        args (argparse.Namespace):
+                        previously parsed arguments
+
+    Raises:
+        SystemExit:     0 if okay
+                        2 if Smart-Remove is not configured
+    """
+    setQuiet(args)
+    printHeader()
+    cfg = getConfig(args)
+    sn = snapshots.Snapshots(cfg)
+
+    enabled, keep_all, keep_one_per_day, keep_one_per_week, keep_one_per_month = cfg.smartRemove()
+    if enabled:
+        _mount(cfg)
+        del_snapshots = sn.smartRemoveList(datetime.today(),
+                                           keep_all,
+                                           keep_one_per_day,
+                                           keep_one_per_week,
+                                           keep_one_per_month)
+        logger.info('Smart Remove will remove {} snapshots'.format(len(del_snapshots)))
+        sn.smartRemove(del_snapshots, log = logger.info)
+        _umount(cfg)
+        sys.exit(RETURN_OK)
+    else:
+        logger.error('Smart Remove is not configured.')
+        sys.exit(RETURN_NO_CFG)
+
+def restore(args):
+    """
+    Command for restoring files from snapshots.
+
+    Args:
+        args (argparse.Namespace):
+                        previously parsed arguments
+
+    Raises:
+        SystemExit:     0
+    """
     setQuiet(args)
     printHeader()
     cfg = getConfig(args)
     _mount(cfg)
+    if cfg.backupOnRestore() and not args.no_local_backup:
+        backup = True
+    else:
+        backup = args.local_backup
     cli.restore(cfg,
                 args.SNAPSHOT_ID,
                 args.WHAT,
                 args.WHERE,
                 delete = args.delete,
-                backup = args.local_backup,
-                no_backup = args.no_local_backup)
+                backup = backup,
+                only_new = args.only_new)
     _umount(cfg)
     sys.exit(RETURN_OK)
 
 def checkConfig(args):
-    '''command for checking the config file.
+    """
+    Command for checking the config file.
 
-    args:   argparse.ArgumentParser instance
-    '''
+    Args:
+        args (argparse.Namespace):
+                        previously parsed arguments
+
+    Raises:
+        SystemExit:     0 if config is okay, 1 if not
+    """
     force_stdout = setQuiet(args)
     printHeader()
     cfg = getConfig(args)
     if cli.checkConfig(cfg, crontab = not args.no_crontab):
         print("\nConfig %(cfg)s profile '%(profile)s' is fine."
               % {'cfg': cfg._LOCAL_CONFIG_PATH,
-                 'profile': cfg.get_profile_name()},
+                 'profile': cfg.profileName()},
               file = force_stdout)
         sys.exit(RETURN_OK)
     else:
         print("\nConfig %(cfg)s profile '%(profile)s' has errors."
               % {'cfg': cfg._LOCAL_CONFIG_PATH,
-                 'profile': cfg.get_profile_name()},
+                 'profile': cfg.profileName()},
               file = force_stdout)
         sys.exit(RETURN_ERR)
 
 if __name__ == '__main__':
-    start_app()
+    startApp()
