@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #    Back In Time
-#    Copyright (C) 2012-2017 Germar Reitze
+#    Copyright (C) 2012-2019 Germar Reitze
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -26,31 +26,33 @@ import bcolors
 def restore(cfg, snapshot_id = None, what = None, where = None, **kwargs):
     if what is None:
         what = input('File to restore: ')
-    what = tools.prepare_path(os.path.abspath(os.path.expanduser(what)))
+    what = tools.preparePath(os.path.abspath(os.path.expanduser(what)))
 
     if where is None:
         where = input('Restore to (empty for original path): ')
     if where:
-        where = tools.prepare_path(os.path.abspath(os.path.expanduser(where)))
+        where = tools.preparePath(os.path.abspath(os.path.expanduser(where)))
 
-    snapshots_ = snapshots.Snapshots(cfg)
-    snapshot_id = selectSnapshot(snapshots_, snapshot_id, 'SnapshotID to restore')
+    snapshotsList = snapshots.listSnapshots(cfg)
+
+    sid = selectSnapshot(snapshotsList, cfg, snapshot_id, 'SnapshotID to restore')
     print('')
-    RestoreDialog(cfg, snapshots_, snapshot_id, what, where, **kwargs).run()
+    RestoreDialog(cfg, sid, what, where, **kwargs).run()
 
 def remove(cfg, snapshot_ids = None, force = None):
-    snapshots_ = snapshots.Snapshots(cfg)
+    snapshotsList = snapshots.listSnapshots(cfg)
     if not snapshot_ids:
         snapshot_ids = (None,)
-    sids = [selectSnapshot(snapshots_, sid, 'SnapshotID to remove') for sid in snapshot_ids]
+    sids = [selectSnapshot(snapshotsList, cfg, sid, 'SnapshotID to remove') for sid in snapshot_ids]
 
     if not force:
         print('Do you really want to remove this snapshots?')
-        [print(snapshots_.get_snapshot_display_name(sid)) for sid in sids]
+        [print(sid.displayName) for sid in sids]
         if not 'yes' == input('(no/yes): '):
             return
 
-    [snapshots_.remove_snapshot(sid) for sid in sids]
+    s = snapshots.Snapshots(cfg)
+    [s.remove(sid) for sid in sids]
 
 def checkConfig(cfg, crontab = True):
     import mount
@@ -68,16 +70,16 @@ def checkConfig(cfg, crontab = True):
     def errorHandler(msg):
         print(bcolors.WARNING + 'WARNING: ' + bcolors.ENDC + msg)
 
-    cfg.set_error_handler(errorHandler)
-    mode = cfg.get_snapshots_mode()
+    cfg.setErrorHandler(errorHandler)
+    mode = cfg.snapshotsMode()
 
     if cfg.SNAPSHOT_MODES[mode][0] is not None:
-        #pre_mount_check
+        #preMountCheck
         test = 'Run mount tests'
         announceTest()
         mnt = mount.Mount(cfg = cfg, tmp_mount = True)
         try:
-            mnt.pre_mount_check(mode = mode, first_run = True)
+            mnt.preMountCheck(mode = mode, first_run = True)
         except MountException as ex:
             failed()
             print(str(ex))
@@ -97,9 +99,9 @@ def checkConfig(cfg, crontab = True):
 
     test = 'Check/prepair snapshot path'
     announceTest()
-    snapshots_path = cfg.get_snapshots_path(mode = mode, tmp_mount = True)
+    snapshots_path = cfg.snapshotsPath(mode = mode, tmp_mount = True)
 
-    if not cfg.set_snapshots_path( snapshots_path, mode = mode ):
+    if not cfg.setSnapshotsPath(snapshots_path, mode = mode):
         failed()
         return False
     okay()
@@ -118,7 +120,7 @@ def checkConfig(cfg, crontab = True):
 
     test = 'Check config'
     announceTest()
-    if not cfg.check_config():
+    if not cfg.checkConfig():
         failed()
         return False
     okay()
@@ -126,29 +128,31 @@ def checkConfig(cfg, crontab = True):
     if crontab:
         test = 'Install crontab'
         announceTest()
-        if not cfg.setup_cron():
+        if not cfg.setupCron():
             failed()
             return False
         okay()
 
     return True
 
-def selectSnapshot(snapshots_, snapshot_id = None, msg = 'SnapshotID'):
-    '''check if given snapshot is valid. If not print a list of all
-    snapshots and ask to choose one'''
-    snapshot_list = snapshots_.get_snapshots_list()
-    len_snapshots = len(snapshot_list)
+def selectSnapshot(snapshotsList, cfg, snapshot_id = None, msg = 'SnapshotID'):
+    """
+    check if given snapshot is valid. If not print a list of all
+    snapshots and ask to choose one
+    """
+    len_snapshots = len(snapshotsList)
 
     if not snapshot_id is None:
-        if len(snapshot_id) == 19:
-            if snapshot_id in snapshot_list:
-                return snapshot_id
+        try:
+            sid = snapshots.SID(snapshot_id, cfg)
+            if sid in snapshotsList:
+                return sid
             else:
                 print('SnapshotID %s not found.' % snapshot_id)
-        else:
+        except ValueError:
             try:
                 index = int(snapshot_id)
-                return snapshot_list[index]
+                return snapshotsList[index]
             except (ValueError, IndexError):
                 print('Invalid SnaphotID index: %s' % snapshot_id)
     snapshot_id = None
@@ -165,20 +169,22 @@ def selectSnapshot(snapshots_, snapshot_id = None, msg = 'SnapshotID'):
             index = row + column * rows
             if index > len_snapshots - 1:
                 continue
-            line.append('{i:>4}: {s}'.format(i = index, s = snapshot_list[index]))
+            line.append('{i:>4}: {s}'.format(i = index, s = snapshotsList[index]))
         print(' '.join(line))
     print('')
     while snapshot_id is None:
         try:
-            sid = int(input(msg + ' ( 0 - %d ): ' % (len_snapshots - 1) ))
-            snapshot_id = snapshot_list[sid]
+            index = int(input(msg + ' (0 - %d): ' % (len_snapshots - 1)))
+            snapshot_id = snapshotsList[index]
         except (ValueError, IndexError):
             print('Invalid Input')
             continue
     return snapshot_id
 
 def terminalSize():
-    '''get terminal size'''
+    """
+    get terminal size
+    """
     for fd in (sys.stdin, sys.stdout, sys.stderr):
         try:
             import fcntl, termios, struct
@@ -188,34 +194,34 @@ def terminalSize():
     return [24, 80]
 
 def frame(msg, size = 32):
-    ret  = ' ┌' + '─' * size +       '┐\n'
-    ret += ' │' + msg.center(size) + '│\n'
-    ret += ' └' + '─' * size +       '┘'
+    ret  = ' +' + '-' * size +       '+\n'
+    ret += ' |' + msg.center(size) + '|\n'
+    ret += ' +' + '-' * size +       '+'
     return ret
 
 class RestoreDialog(object):
-    def __init__(self, cfg, snapshots_, snapshot_id, what, where, **kwargs):
+    def __init__(self, cfg, sid, what, where, **kwargs):
         self.config = cfg
-        self.snapshots = snapshots_
-        self.snapshot_id = snapshot_id
+        self.sid = sid
         self.what = what
         self.where = where
         self.kwargs = kwargs
 
-        self.log_file = self.config.get_restore_log_file()
-        if os.path.exists(self.log_file):
-            os.remove(self.log_file)
+        self.logFile = self.config.restoreLogFile()
+        if os.path.exists(self.logFile):
+            os.remove(self.logFile)
 
     def callback(self, line, *params):
         if not line:
             return
         print(line)
-        with open(self.log_file, 'a') as log:
+        with open(self.logFile, 'a') as log:
             log.write(line + '\n')
 
     def run(self):
-        self.snapshots.restore(self.snapshot_id, self.what, self.callback, self.where, **self.kwargs)
-        print('\nLog saved to %s' % self.log_file)
+        s = snapshots.Snapshots(self.config)
+        s.restore(self.sid, self.what, self.callback, self.where, **self.kwargs)
+        print('\nLog saved to %s' % self.logFile)
 
 class BackupJobDaemon(tools.Daemon):
     def __init__(self, func, args):
