@@ -1,5 +1,5 @@
 #    Back In Time
-#    Copyright (C) 2008-2017 Oprea Dan, Bart de Koning, Richard Bailey, Germar Reitze
+#    Copyright (C) 2008-2019 Oprea Dan, Bart de Koning, Richard Bailey, Germar Reitze
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -47,8 +47,8 @@ gettext.textdomain('backintime')
 
 class Config(configfile.ConfigFileWithProfiles):
     APP_NAME = 'Back In Time'
-    VERSION = '1.2.0~alpha17'
-    COPYRIGHT = 'Copyright (C) 2008-2017 Oprea Dan, Bart de Koning, Richard Bailey, Germar Reitze'
+    VERSION = '1.2.1'
+    COPYRIGHT = 'Copyright (C) 2008-2019 Oprea Dan, Bart de Koning, Richard Bailey, Germar Reitze'
     CONFIG_VERSION = 6
 
     NONE = 0
@@ -390,11 +390,13 @@ class Config(configfile.ConfigFileWithProfiles):
                 self.notifyError(_('Can\'t write to: %s\nAre you sure you have write access ?' % value))
                 return False
 
-            path1 = os.path.join(value, 'backintime')
-            os.chmod(path1, 0o777)
-
-            path1 = os.path.join(value, 'backintime', host)
-            os.chmod(path1, 0o777)
+            for p in (os.path.join(value, 'backintime'),
+                      os.path.join(value, 'backintime', host)):
+                try:
+                    os.chmod(p, 0o777)
+                except PermissionError as e:
+                    msg = "Failed to change permissions world writeable for '{}': {}"
+                    logger.warning(msg.format(p, str(e)), self)
 
         #Test filesystem
         fs = tools.filesystem(full_path)
@@ -1219,40 +1221,6 @@ class Config(configfile.ConfigFileWithProfiles):
         #?syslog and TTY again.
         return self.profileBoolValue('user_callback.no_logging', False, profile_id)
 
-    ###########################################################################
-
-    def takeSnapshotUserScript(self, step, profile_id = None):
-        #?Run this scrip on events defined by <STEP>.\nPossible events for
-        #?<STEP>:\n  before\n  after\n  new_snapshot\n  error;absolute path
-        return self.profileStrValue ("snapshots.take_snapshot.%s.user.script" % step, '', profile_id)
-
-    def setTakeSnapshotUserScript(self, step, path, profile_id = None):
-        self.setProfileStrValue("snapshots.take_snapshot.%s.user.script" % step, path, profile_id)
-
-    def takeSnapshotUserScriptBefore(self, profile_id = None):
-        return self.takeSnapshotUserScript('before', profile_id)
-
-    def setTakeSnapshotUserScriptBefore(self, path, profile_id = None):
-        self.setTakeSnapshotUserScript('before', path, profile_id)
-
-    def takeSnapshotUserScriptAfter(self, profile_id = None):
-        return self.takeSnapshotUserScript('after', profile_id)
-
-    def setTakeSnapshotUserScriptAfter(self, path, profile_id = None):
-        self.setTakeSnapshotUserScript('after', path, profile_id)
-
-    def takeSnapshotUserScriptNewSnapshot(self, profile_id = None):
-        return self.takeSnapshotUserScript('new_snapshot', profile_id = None)
-
-    def setTakeSnapshotUserScriptNewSnapshot(self, path, profile_id = None):
-        self.setTakeSnapshotUserScript('new_snapshot', path, profile_id)
-
-    def takeSnapshotUserScriptError(self, profile_id = None):
-        return self.takeSnapshotUserScript('error', profile_id)
-
-    def setTakeSnapshotUserScriptError(self, path, profile_id = None):
-        self.setTakeSnapshotUserScript('error', path, profile_id)
-
     def globalFlock(self):
         #?Prevent multiple snapshots (from different profiles or users) to be run at the same time
         return self.boolValue('global.use_flock', False)
