@@ -1,4 +1,4 @@
-#    Copyright (C) 2012-2017 Germar Reitze
+#    Copyright (C) 2012-2019 Germar Reitze
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@ import stat
 import tools
 import threading
 import tempfile
+from contextlib import contextmanager
 
 import logger
 
@@ -58,7 +59,7 @@ class FIFO(object):
         for input.
         """
         #sys.stdout.write('read fifo\n')
-        if not self.is_fifo():
+        if not self.isFifo():
             sys.exit(1)
         self.alarm.start(timeout)
         with open(self.fifo, 'r') as fifo:
@@ -72,14 +73,14 @@ class FIFO(object):
         for an other process that will read this.
         """
         #sys.stdout.write('write fifo\n')
-        if not self.is_fifo():
+        if not self.isFifo():
             sys.exit(1)
         self.alarm.start(timeout)
         with open(self.fifo, 'w') as fifo:
             fifo.write(string)
         self.alarm.stop()
 
-    def is_fifo(self):
+    def isFifo(self):
         """
         make sure file is still a FIFO and has correct permissions
         """
@@ -111,6 +112,12 @@ class TempPasswordThread(threading.Thread):
         self.temp_file = os.path.join(tempfile.mkdtemp(), 'FIFO')
         self.fifo = FIFO(self.temp_file)
 
+    @contextmanager
+    def starter(self):
+        self.start()
+        yield
+        self.stop()
+
     def run(self):
         self.fifo.create()
         self.fifo.write(self.pw)
