@@ -1,5 +1,5 @@
 # Back In Time
-# Copyright (C) 2015 Germar Reitze
+# Copyright (C) 2015-2019 Germar Reitze
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,11 +15,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-from test import test_applicationinstance
-from test import test_argparser
-from test import test_configfile
-from test import test_snapshots
-from test import test_tools
+from test import *
 
 if __name__ == '__main__':
     pass
