@@ -1,5 +1,5 @@
 #    Back In Time
-#    Copyright (C) 2008-2017 Oprea Dan, Bart de Koning, Richard Bailey, Germar Reitze, Taylor Raack
+#    Copyright (C) 2008-2019 Oprea Dan, Bart de Koning, Richard Bailey, Germar Reitze, Taylor Raack
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -449,11 +449,14 @@ def checkXServer():
     Returns:
         bool:   ``True`` if X11 server is running
     """
-    proc = subprocess.Popen(['xdpyinfo'],
-                            stdout = subprocess.DEVNULL,
-                            stderr = subprocess.DEVNULL)
-    proc.communicate()
-    return proc.returncode == 0
+    if checkCommand('xdpyinfo'):
+        proc = subprocess.Popen(['xdpyinfo'],
+                                stdout = subprocess.DEVNULL,
+                                stderr = subprocess.DEVNULL)
+        proc.communicate()
+        return proc.returncode == 0
+    else:
+        return False
 
 def preparePath(path):
     """
@@ -934,9 +937,22 @@ def uuidFromDev(dev):
     """
     if dev and os.path.exists(dev):
         dev = os.path.realpath(dev)
-        for uuid in os.listdir(DISK_BY_UUID):
-            if dev == os.path.realpath(os.path.join(DISK_BY_UUID, uuid)):
-                return uuid
+        if os.path.exists(DISK_BY_UUID):
+            for uuid in os.listdir(DISK_BY_UUID):
+                if dev == os.path.realpath(os.path.join(DISK_BY_UUID, uuid)):
+                    return uuid
+        else:
+            c = re.compile(b'.*\sUUID="([^"]*)".*')
+            try:
+                # If device does not exist, blkid will exit with a non-zero code
+                blkid = subprocess.check_output(['blkid', dev],
+                                                stderr = subprocess.DEVNULL)
+                uuid = c.findall(blkid)
+                if uuid:
+                    return uuid[0].decode('UTF-8')
+            except:
+                pass
+
     c = re.compile(b'.*?ID_FS_UUID=(\S+)')
     try:
         udevadm = subprocess.check_output(['udevadm', 'info', '--name=%s' % dev],
